@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# Lint as: python2, python3
 """Utilities for Python Fire's tests."""
 
 from __future__ import absolute_import
@@ -19,6 +20,7 @@ from __future__ import division
 from __future__ import print_function
 
 import contextlib
+import os
 import re
 import sys
 import unittest
@@ -44,6 +46,7 @@ class BaseTestCase(unittest.TestCase):
       stdout: (str) regexp to match against stdout (None will check no stdout)
       stderr: (str) regexp to match against stderr (None will check no stderr)
       capture: (bool, default True) do not bubble up stdout or stderr
+
     Yields:
       Yields to the wrapped context.
     """
@@ -70,6 +73,12 @@ class BaseTestCase(unittest.TestCase):
           raise AssertionError('%s: Expected %r to match %r' %
                                (name, value, regexp))
 
+  def assertRaisesRegex(self, *args, **kwargs):  # pylint: disable=arguments-differ
+    if sys.version_info.major == 2:
+      return super(BaseTestCase, self).assertRaisesRegexp(*args, **kwargs)  # pylint: disable=deprecated-method
+    else:
+      return super(BaseTestCase, self).assertRaisesRegex(*args, **kwargs)  # pylint: disable=no-member
+
   @contextlib.contextmanager
   def assertRaisesFireExit(self, code, regexp='.*'):
     """Asserts that a FireExit error is raised in the context.
@@ -80,6 +89,7 @@ class BaseTestCase(unittest.TestCase):
     Args:
       code: The status code that the FireExit should contain.
       regexp: stdout must match this regex.
+
     Yields:
       Yields to the wrapped context.
     """
@@ -89,12 +99,24 @@ class BaseTestCase(unittest.TestCase):
           yield
         except core.FireExit as exc:
           if exc.code != code:
-            raise AssertionError('Incorrect exit code: %r != %r' % (exc.code,
-                                                                    code))
+            raise AssertionError('Incorrect exit code: %r != %r' %
+                                 (exc.code, code))
           self.assertIsInstance(exc.trace, trace.FireTrace)
           raise
 
 
+@contextlib.contextmanager
+def ChangeDirectory(directory):
+  """Context manager to mock a directory change and revert on exit."""
+  cwdir = os.getcwd()
+  os.chdir(directory)
+
+  try:
+    yield directory
+  finally:
+    os.chdir(cwdir)
+
+
 # pylint: disable=invalid-name
 main = unittest.main
 skip = unittest.skip
